<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:date="http://exslt.org/dates-and-times" extension-element-prefixes="date" exclude-result-prefixes="date">
	<xsl:output method="html"/>
	<xsl:template name="DurationDisplay">
		<xsl:param name="longdate"/>
		<xsl:variable name="seconds" select="(number($longdate) mod 60000) div 1000.0"/>
		<xsl:variable name="minutes" select="floor((number($longdate) div 60000) mod 60)"/>
		<xsl:variable name="hours" select="floor((number($longdate) div 3600000) mod 24)"/>
		<xsl:variable name="days" select="floor(number($longdate) div 86400000)"/>
		<xsl:value-of select="concat(format-number($days, '#0'), 'd', format-number($hours, '#0'), 'h', format-number($minutes, '#0'), 'm', $seconds, 's')"/>
	</xsl:template>
	<xsl:key name="ClientClassName" match="/javaprssrvr/clients/clientrcv" use="class/@name"/>
	<xsl:key name="NotTCPClientKey" match="/javaprssrvr/clients/clientrcv" use="not(class/@name = 'TCPClientRcv' or class/@name = 'RemoteServer' or class/@name = 'UpstreamClientRcv')"/>
	<xsl:template match="/">
		<html>
			<head>
				<title>
					<xsl:value-of select="javaprssrvr/dupeprocessor/servercall"/> Status Page</title>
				<meta content="noindex,nofollow" name="robots"/>
			</head>
			<body bgColor="#606060">
				<center>
					<table bgColor="#d0d0d0" border="2">
						<thead>
							<tr align="center" bgColor="#ffd700">
								<th colspan="2" align="center">
									<xsl:value-of select="javaprssrvr/@name"/>&#xA0;
									<xsl:value-of select="javaprssrvr/@version"/>
									<xsl:value-of select="javaprssrvr/@revision"/>
									<br/>Copyright &#xA9;
                                                        		<xsl:value-of select="date:year(date:date-time())"/>
									- Peter Loveall AE5PL
								</th>
							</tr>
							<tr align="center" bgColor="#909090">
								<th colspan="2" align="center">
                                                                    <xsl:value-of select="date:date-time()"/>
								</th>
							</tr>
						</thead>
						<tbody>
							<tr align="right">
								<td align="left">Server ID</td>
								<td>
									<xsl:value-of select="javaprssrvr/dupeprocessor/servercall"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">OS</td>
								<td>
									<xsl:value-of select="javaprssrvr/java/os"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">JVM</td>
								<td>
									<xsl:value-of select="javaprssrvr/java/jre"/>
									<br/>
									<xsl:value-of select="javaprssrvr/java/jre/@specversion"/>
								</td>
							</tr>
							<tr align="right">
								<td colspan="2" bgColor="#909090"/>
							</tr>
							<tr align="right">
								<td align="left">TCP Bytes In</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/clients/rcvdtotals/@bytes, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">UDP Bytes In</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/clients/rcvdtotals/udp/@bytes, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Bytes In</td>
								<td>
									<xsl:value-of select="format-number(number(javaprssrvr/clients/rcvdtotals/@bytes) + number(javaprssrvr/clients/rcvdtotals/udp/@bytes), '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Average bps In</td>
								<td>
									<xsl:value-of select="format-number((number(javaprssrvr/clients/rcvdtotals/@bytes) + number(javaprssrvr/clients/rcvdtotals/udp/@bytes)) * 10000 div number(javaprssrvr/java/time/up/@millis), '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">TCP Bytes Out</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/clients/xmtdtotals/@bytes, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">UDP Bytes Out</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/clients/xmtdtotals/udp/@bytes, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Bytes Out</td>
								<td>
									<xsl:value-of select="format-number(number(javaprssrvr/clients/xmtdtotals/@bytes) + number(javaprssrvr/clients/xmtdtotals/udp/@bytes), '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Average bps Out</td>
								<td>
									<xsl:value-of select="format-number((number(javaprssrvr/clients/xmtdtotals/@bytes) + number(javaprssrvr/clients/xmtdtotals/udp/@bytes)) * 10000 div number(javaprssrvr/java/time/up/@millis), '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td colspan="2" bgColor="#909090"/>
							</tr>
							<tr align="right">
								<td align="left">Total Valid Packets</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/dupeprocessor/goodpackets/@packets, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Duplicate Packets</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/dupeprocessor/duplicatepackets/@packets, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Rejected Packets</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/dupeprocessor/blockedpackets/@packets, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Looped Packets</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/dupeprocessor/loopedpackets/@packets, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Total Packets Processed</td>
								<td>
									<xsl:value-of select="format-number(javaprssrvr/dupeprocessor/goodpackets/@packets + javaprssrvr/dupeprocessor/duplicatepackets/@packets + javaprssrvr/dupeprocessor/blockedpackets/@packets + javaprssrvr/dupeprocessor/loopedpackets/@packets, '#,##0')"/>
								</td>
							</tr>
							<tr align="right">
								<td colspan="2" bgColor="#909090"/>
							</tr>
							<tr align="right">
								<td align="left">Total Clients</td>
								<td>
									<xsl:value-of select="javaprssrvr/clients/@total"/>
								</td>
							</tr>
							<tr align="right">
								<td align="left">Current Clients</td>
								<td>
									<xsl:value-of select="javaprssrvr/clients/@current"/>
								</td>
							</tr>
						</tbody>
					</table>
					<p>&#xA0;</p>
					<table bgColor="#d0d0d0" border="2">
						<thead>
							<tr align="center" bgColor="#ffd700">
								<th colspan="2" align="center">Available Ports</th>
							</tr>
							<tr align="center" bgColor="#909090">
								<th>Port Number</th>
								<th>Description</th>
							</tr>
						</thead>
						<tbody>
							<xsl:for-each select="javaprssrvr/listenerports/portlistener">
								<xsl:sort select="description/@Port" data-type="number"/>
								<xsl:if test="description">
									<tr align="center">
										<td>
											<xsl:value-of select="description/@Port"/>
										</td>
										<td>
											<xsl:value-of select="description"/>
										</td>
									</tr>
								</xsl:if>
							</xsl:for-each>
						</tbody>
					</table>
					<xsl:if test="count(key('ClientClassName', 'RemoteServer'))&gt;0">
						<p>&#xA0;</p>
						<table bgColor="#d0d0d0" border="2">
							<thead>
								<tr align="center" bgColor="#ffd700">
									<th colSpan="16">Remote Peer Servers</th>
								</tr>
								<tr align="center" bgColor="#909090">
									<th>Client IP</th>
									<th>Callsign</th>
									<th>Packets
										<br/>Rcvd</th>
									<th>Packets
										<br/>Sent</th>
									<th>Bytes
										<br/>Rcvd</th>
									<th>Bytes
										<br/>Sent</th>
									<th>Rcv
										<br/>bps</th>
									<th>Send
										<br/>bps</th>
									<th>Last
										<br/>Packet In</th>
								</tr>
							</thead>
							<tbody>
								<xsl:for-each select="key('ClientClassName', 'RemoteServer')">
									<xsl:sort select="login/callssid"/>
									<tr align="right">
										<td align="center">
											<a href="http://{remoteserver}:14501">
												<xsl:value-of select="remoteserver"/>
											</a>
										</td>
										<td align="center">
											<xsl:value-of select="login/callssid"/>
										</td>
										<td>
											<xsl:value-of select="format-number(rcvdfrom/udp/@packets, '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/udp/@packets, '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number(rcvdfrom/udp/@bytes, '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/udp/@bytes, '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number((number(rcvdfrom/@bytes) + number(rcvdfrom/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number((number(clientxmt/sentto/@bytes) + number(clientxmt/sentto/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:choose>
												<xsl:when test="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc) &gt;= 0">
													<xsl:call-template name="DurationDisplay">
														<xsl:with-param name="longdate" select="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc)"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>0d0h0m0s</xsl:otherwise>
											</xsl:choose>
										</td>
									</tr>
								</xsl:for-each>
							</tbody>
						</table>
					</xsl:if>
					<xsl:if test="count(key('NotTCPClientKey', 'true'))&gt;0">
						<p>&#xA0;</p>
						<table bgColor="#d0d0d0" border="2">
							<thead>
								<tr align="center" bgColor="#ffd700">
									<th colSpan="16">Internal Clients</th>
								</tr>
								<tr align="center" bgColor="#909090">
									<th>Callsign</th>
									<th>Verified</th>
									<th>Software</th>
									<th>SA Setting</th>
									<th>Packets
										<br/>Rcvd</th>
									<th>Packets
										<br/>Sent</th>
									<th>Bytes
										<br/>Rcvd</th>
									<th>Bytes
										<br/>Sent</th>
									<th>Rcv
										<br/>bps</th>
									<th>Send
										<br/>bps</th>
									<th>Last
										<br/>Packet In</th>
								</tr>
							</thead>
							<tbody>
								<xsl:for-each select="key('NotTCPClientKey', 'true')">
									<xsl:sort select="class/@name"/>
									<xsl:sort select="login/callssid"/>
									<tr align="right">
										<td align="center">
											<xsl:choose>
												<xsl:when test="not(login) and not(networkinterface)">Non-APRS</xsl:when>
												<xsl:when test="not(login)">No Login</xsl:when>
												<xsl:when test="contains(login/callssid, '-')">
													<a href="http://www.jfindu.net/lh/{substring-before(login/callssid, '-')}">
														<xsl:value-of select="login/callssid"/>
													</a>
												</xsl:when>
												<xsl:otherwise>
													<a href="http://www.jfindu.net/lh/{login/callssid}">
														<xsl:value-of select="login/callssid"/>
													</a>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td align="center">
											<xsl:value-of select="login/callssid/@verified"/>
										</td>
										<td align="center">
											<xsl:value-of select="login/software"/>&#xA0;
											<xsl:value-of select="login/software/@version"/>
										</td>
										<td align="center">
											<xsl:for-each select="clientxmt/adjuncts">
												<xsl:if test="filteraprsclient/filter">
													<xsl:value-of select="filteraprsclient/filter"/>
												</xsl:if>
											</xsl:for-each>
										</td>
										<td>
											<xsl:value-of select="format-number(rcvdfrom/@packets, '#,##0')"/>
											<xsl:if test="rcvdfrom/udp/@packets &gt; 0">
												<br/>
												<xsl:value-of select="format-number(rcvdfrom/udp/@packets, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/@packets, '#,##0')"/>
											<xsl:if test="clientxmt/sentto/udp/@packets &gt; 0">
												<br/>
												<xsl:value-of select="format-number(clientxmt/sentto/udp/@packets, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(number(rcvdfrom/@bytes), '#,##0')"/>
											<xsl:if test="rcvdfrom/udp/@bytes &gt; 0">
												<br/>
												<xsl:value-of select="format-number(rcvdfrom/udp/@bytes, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/@bytes, '#,##0')"/>
											<xsl:if test="clientxmt/sentto/udp/@bytes &gt; 0">
												<br/>
												<xsl:value-of select="format-number(clientxmt/sentto/udp/@bytes, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number((number(rcvdfrom/@bytes) + number(rcvdfrom/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number((number(clientxmt/sentto/@bytes) + number(clientxmt/sentto/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:choose>
												<xsl:when test="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc) &gt;= 0">
													<xsl:call-template name="DurationDisplay">
														<xsl:with-param name="longdate" select="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc)"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>0d0h0m0s</xsl:otherwise>
											</xsl:choose>
										</td>
									</tr>
								</xsl:for-each>
							</tbody>
						</table>
					</xsl:if>
					<xsl:if test="count(key('ClientClassName', 'UpstreamClientRcv'))&gt;0">
						<p>&#xA0;</p>
						<table bgColor="#d0d0d0" border="2">
							<thead>
								<tr align="center" bgColor="#ffd700">
									<th colSpan="16">Upstream Servers</th>
								</tr>
								<tr align="center" bgColor="#909090">
									<th>Client IP</th>
									<th>Callsign</th>
									<th>Verified</th>
									<th>Software</th>
									<th>Connected</th>
									<th>Packets
										<br/>Rcvd</th>
									<th>Packets
										<br/>Sent</th>
									<th>Bytes
										<br/>Rcvd</th>
									<th>Bytes
										<br/>Sent</th>
									<th>Rcv
										<br/>bps</th>
									<th>Send
										<br/>bps</th>
									<th>Last
										<br/>Packet In</th>
								</tr>
							</thead>
							<tbody>
								<xsl:for-each select="key('ClientClassName', 'UpstreamClientRcv')">
									<xsl:sort select="time/connect/@utc" data-type="number"/>
									<tr align="right">
										<td align="center">
											<xsl:choose>
												<xsl:when test="client">
													<a href="http://{client}:14501">
														<xsl:value-of select="client"/>
													</a>
												</xsl:when>
												<xsl:when test="remoteserver">
													<a href="http://{remoteserver}:14501">
														<xsl:value-of select="remoteserver"/>
													</a>
												</xsl:when>
												<xsl:otherwise>Internal</xsl:otherwise>
											</xsl:choose>
										</td>
										<td align="center">
											<xsl:choose>
												<xsl:when test="not(login) and not(networkinterface)">Non-APRS</xsl:when>
												<xsl:when test="not(login)">No Login</xsl:when>
												<xsl:when test="contains(login/callssid, '-')">
													<a href="http://www.jfindu.net/lh/{substring-before(login/callssid, '-')}">
														<xsl:value-of select="login/callssid"/>
													</a>
												</xsl:when>
												<xsl:otherwise>
													<a href="http://www.jfindu.net/lh/{login/callssid}">
														<xsl:value-of select="login/callssid"/>
													</a>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td align="center">
											<xsl:value-of select="login/callssid/@verified"/>
										</td>
										<td align="center">
											<xsl:value-of select="login/software"/>&#xA0;
											<xsl:value-of select="login/software/@version"/>
										</td>
										<td align="center">
											<xsl:choose>
												<xsl:when test="/javaprssrvr/java/time/current/@utc - time/connect/@utc &gt;= 0">
													<xsl:call-template name="DurationDisplay">
														<xsl:with-param name="longdate" select="/javaprssrvr/java/time/current/@utc - time/connect/@utc"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>0d0h0m0s</xsl:otherwise>
											</xsl:choose>
										</td>
										<td>
											<xsl:value-of select="format-number(rcvdfrom/@packets, '#,##0')"/>
											<xsl:if test="rcvdfrom/udp/@packets &gt; 0">
												<br/>
												<xsl:value-of select="format-number(rcvdfrom/udp/@packets, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/@packets, '#,##0')"/>
											<xsl:if test="clientxmt/sentto/udp/@packets &gt; 0">
												<br/>
												<xsl:value-of select="format-number(clientxmt/sentto/udp/@packets, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(number(rcvdfrom/@bytes), '#,##0')"/>
											<xsl:if test="rcvdfrom/udp/@bytes &gt; 0">
												<br/>
												<xsl:value-of select="format-number(rcvdfrom/udp/@bytes, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number(clientxmt/sentto/@bytes, '#,##0')"/>
											<xsl:if test="clientxmt/sentto/udp/@bytes &gt; 0">
												<br/>
												<xsl:value-of select="format-number(clientxmt/sentto/udp/@bytes, '#,##0')"/>u</xsl:if>
										</td>
										<td>
											<xsl:value-of select="format-number((number(rcvdfrom/@bytes) + number(rcvdfrom/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:value-of select="format-number((number(clientxmt/sentto/@bytes) + number(clientxmt/sentto/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
										</td>
										<td>
											<xsl:choose>
												<xsl:when test="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc) &gt;= 0">
													<xsl:call-template name="DurationDisplay">
														<xsl:with-param name="longdate" select="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc)"/>
													</xsl:call-template>
												</xsl:when>
												<xsl:otherwise>0d0h0m0s</xsl:otherwise>
											</xsl:choose>
										</td>
									</tr>
								</xsl:for-each>
							</tbody>
						</table>
					</xsl:if>
					<p>&#xA0;</p>
					<table bgColor="#d0d0d0" border="2">
						<thead>
							<tr align="center" bgColor="#ffd700">
								<th colSpan="16">Remote Clients</th>
							</tr>
							<tr align="center" bgColor="#909090">
								<th>Remote</th>
								<th>Callsign</th>
								<th>Verified</th>
								<th>Software</th>
								<th>SA Setting</th>
								<th>Connected</th>
								<th>Packets
									<br/>Rcvd</th>
								<th>Packets
									<br/>Sent</th>
								<th>Bytes
									<br/>Rcvd</th>
								<th>Bytes
									<br/>Sent</th>
								<th>Rcv
									<br/>bps</th>
								<th>Send
									<br/>bps</th>
								<th>Last
									<br/>Packet In</th>
							</tr>
						</thead>
						<tbody>
							<xsl:for-each select="key('ClientClassName', 'TCPClientRcv')">
								<xsl:sort select="time/connect/@utc" data-type="number"/>
								<tr align="right">
									<td align="center">
										<xsl:choose>
											<xsl:when test="client">
												<a href="http://{client}:14501">
													<xsl:value-of select="client"/>
												</a>
											</xsl:when>
											<xsl:when test="remoteserver">
												<a href="http://{remoteserver}:14501">
													<xsl:value-of select="remoteserver"/>
												</a>
											</xsl:when>
											<xsl:otherwise>Internal</xsl:otherwise>
										</xsl:choose>
									</td>
									<td align="center">
										<xsl:choose>
											<xsl:when test="not(login) and not(networkinterface)">Non-APRS</xsl:when>
											<xsl:when test="not(login)">No Login</xsl:when>
											<xsl:when test="contains(login/callssid, '-')">
												<a href="http://www.jfindu.net/lh/{substring-before(login/callssid, '-')}">
													<xsl:value-of select="login/callssid"/>
												</a>
											</xsl:when>
											<xsl:otherwise>
												<a href="http://www.jfindu.net/lh/{login/callssid}">
													<xsl:value-of select="login/callssid"/>
												</a>
											</xsl:otherwise>
										</xsl:choose>
									</td>
									<td align="center">
										<xsl:value-of select="login/callssid/@verified"/>
									</td>
									<td align="center">
										<xsl:value-of select="login/software"/>&#xA0;
										<xsl:value-of select="login/software/@version"/>
									</td>
									<td align="center">
										<xsl:for-each select="clientxmt/adjuncts">
											<xsl:if test="filteraprsclient/filter">
												<xsl:value-of select="filteraprsclient/filter"/>
											</xsl:if>
										</xsl:for-each>
									</td>
									<td align="center">
										<xsl:choose>
											<xsl:when test="/javaprssrvr/java/time/current/@utc - time/connect/@utc &gt;= 0">
												<xsl:call-template name="DurationDisplay">
													<xsl:with-param name="longdate" select="/javaprssrvr/java/time/current/@utc - time/connect/@utc"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>0d0h0m0s</xsl:otherwise>
										</xsl:choose>
									</td>
									<td>
										<xsl:value-of select="format-number(rcvdfrom/@packets, '#,##0')"/>
										<xsl:if test="rcvdfrom/udp/@packets &gt; 0">
											<br/>
											<xsl:value-of select="format-number(rcvdfrom/udp/@packets, '#,##0')"/>u</xsl:if>
									</td>
									<td>
										<xsl:value-of select="format-number(clientxmt/sentto/@packets, '#,##0')"/>
										<xsl:if test="clientxmt/sentto/udp/@packets &gt; 0">
											<br/>
											<xsl:value-of select="format-number(clientxmt/sentto/udp/@packets, '#,##0')"/>u</xsl:if>
									</td>
									<td>
										<xsl:value-of select="format-number(number(rcvdfrom/@bytes), '#,##0')"/>
										<xsl:if test="rcvdfrom/udp/@bytes &gt; 0">
											<br/>
											<xsl:value-of select="format-number(rcvdfrom/udp/@bytes, '#,##0')"/>u</xsl:if>
									</td>
									<td>
										<xsl:value-of select="format-number(clientxmt/sentto/@bytes, '#,##0')"/>
										<xsl:if test="clientxmt/sentto/udp/@bytes &gt; 0">
											<br/>
											<xsl:value-of select="format-number(clientxmt/sentto/udp/@bytes, '#,##0')"/>u</xsl:if>
									</td>
									<td>
										<xsl:value-of select="format-number((number(rcvdfrom/@bytes) + number(rcvdfrom/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
									</td>
									<td>
										<xsl:value-of select="format-number((number(clientxmt/sentto/@bytes) + number(clientxmt/sentto/udp/@bytes)) * 10000 div (/javaprssrvr/java/time/current/@utc - time/connect/@utc), '#,##0')"/>
									</td>
									<td>
										<xsl:choose>
											<xsl:when test="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc) &gt;= 0">
												<xsl:call-template name="DurationDisplay">
													<xsl:with-param name="longdate" select="number(/javaprssrvr/java/time/current/@utc) - number(time/lastlinein/@utc)"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>0d0h0m0s</xsl:otherwise>
										</xsl:choose>
									</td>
								</tr>
							</xsl:for-each>
						</tbody>
					</table>
				</center>
			</body>
		</html>
	</xsl:template>
</xsl:stylesheet><!-- Stylus Studio meta-information - (c) 2004-2009. Progress Software Corporation. All rights reserved.

<metaInformation>
	<scenarios>
		<scenario default="yes" name="detail.xml" userelativepaths="yes" externalpreview="no" url="detail.xml" htmlbaseurl="" outputurl="" processortype="jaxp" useresolver="no" profilemode="0" profiledepth="" profilelength="" urlprofilexml=""
		          commandline="" additionalpath="" additionalclasspath="" postprocessortype="none" postprocesscommandline="" postprocessadditionalpath="" postprocessgeneratedext="" validateoutput="no" validator="internal" customvalidator="">
			<advancedProp name="sInitialMode" value=""/>
			<advancedProp name="bXsltOneIsOkay" value="true"/>
			<advancedProp name="bSchemaAware" value="false"/>
			<advancedProp name="bGenerateByteCode" value="false"/>
			<advancedProp name="bXml11" value="false"/>
			<advancedProp name="iValidation" value="0"/>
			<advancedProp name="bExtensions" value="true"/>
			<advancedProp name="iWhitespace" value="0"/>
			<advancedProp name="sInitialTemplate" value=""/>
			<advancedProp name="bTinyTree" value="true"/>
			<advancedProp name="xsltVersion" value="2.0"/>
			<advancedProp name="bWarnings" value="true"/>
			<advancedProp name="bUseDTD" value="false"/>
			<advancedProp name="iErrorHandling" value="fatal"/>
		</scenario>
	</scenarios>
	<MapperMetaTag>
		<MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no">
			<SourceSchema srcSchemaPath="detail.xml" srcSchemaRoot="javaprssrvr" AssociatedInstance="" loaderFunction="document" loaderFunctionUsesURI="no"/>
		</MapperInfo>
		<MapperBlockPosition>
			<template match="/">
				<block path="html/body/center/table/tbody/tr[1]/th/xsl:call-template" x="144" y="72"/>
				<block path="html/body/center/table/tbody/tr[6]/td[1]/xsl:value-of" x="24" y="72"/>
				<block path="html/body/center/table/tbody/tr[7]/td[1]/xsl:value-of" x="224" y="32"/>
				<block path="html/body/center/table/tbody/tr[8]/td[1]/xsl:value-of" x="264" y="32"/>
				<block path="html/body/center/table/tbody/tr[9]/td[1]/xsl:value-of" x="184" y="32"/>
				<block path="html/body/center/table/tbody/tr[10]/td[1]/xsl:value-of" x="144" y="32"/>
				<block path="html/body/center/table/tbody/tr[11]/td[1]/xsl:value-of" x="104" y="32"/>
				<block path="html/body/center/table/tbody/tr[12]/td[1]/xsl:value-of" x="64" y="32"/>
				<block path="html/body/center/table/tbody/tr[13]/td[1]/xsl:value-of" x="24" y="32"/>
				<block path="html/body/center/table/tbody/tr[15]/td[1]/xsl:value-of" x="224" y="152"/>
				<block path="html/body/center/table/tbody/tr[16]/td[1]/xsl:value-of" x="264" y="152"/>
				<block path="html/body/center/table/tbody/tr[17]/td[1]/xsl:value-of" x="184" y="152"/>
				<block path="html/body/center/table/tbody/tr[18]/td[1]/xsl:value-of" x="144" y="152"/>
				<block path="html/body/center/table/tbody/tr[19]/td[1]/xsl:value-of" x="104" y="152"/>
				<block path="html/body/center/table[1]/tbody/xsl:for-each" x="74" y="82"/>
				<block path="html/body/center/table[1]/tbody/xsl:for-each/xsl:if" x="144" y="112"/>
				<block path="html/body/center/xsl:if/&gt;[0]" x="178" y="110"/>
				<block path="html/body/center/xsl:if/&gt;[0]/count[0]" x="132" y="104"/>
				<block path="html/body/center/xsl:if" x="224" y="112"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each" x="24" y="112"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td[1]/xsl:value-of" x="64" y="152"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td[2]/xsl:value-of" x="24" y="152"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td[3]/xsl:value-of" x="224" y="192"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td[4]/xsl:value-of" x="264" y="192"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td[5]/xsl:value-of" x="184" y="192"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td[6]/xsl:value-of" x="144" y="192"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td[7]/xsl:value-of" x="104" y="192"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td[8]/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td[8]/xsl:choose/&gt;=[0]" x="148" y="76"/>
				<block path="html/body/center/xsl:if/table/tbody/xsl:for-each/tr/td[8]/xsl:choose/xsl:when/xsl:call-template" x="64" y="192"/>
				<block path="" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/&gt;[0]" x="218" y="110"/>
				<block path="html/body/center/xsl:if[1]/&gt;[0]/count[0]" x="172" y="104"/>
				<block path="html/body/center/xsl:if[1]" x="264" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each" x="224" y="72"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td/xsl:choose/and[0]" x="148" y="76"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td/xsl:choose/contains[2]" x="148" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td/xsl:choose/xsl:when[2]/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td/xsl:choose/xsl:otherwise/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[1]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[2]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[2]/xsl:value-of[1]" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[3]/xsl:for-each" x="164" y="52"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[3]/xsl:for-each/xsl:if" x="194" y="82"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[3]/xsl:for-each/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[4]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[4]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[4]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[4]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[5]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[5]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[5]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[5]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[6]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[6]/xsl:value-of/number[0]" x="178" y="106"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[6]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[6]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[6]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[7]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[7]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[7]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[7]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[8]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[9]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[10]/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[10]/xsl:choose/&gt;=[0]" x="148" y="76"/>
				<block path="html/body/center/xsl:if[1]/table/tbody/xsl:for-each/tr/td[10]/xsl:choose/xsl:when/xsl:call-template" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/&gt;[0]" x="138" y="110"/>
				<block path="html/body/center/xsl:if[2]/&gt;[0]/count[0]" x="92" y="104"/>
				<block path="html/body/center/xsl:if[2]" x="184" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each" x="264" y="72"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td/xsl:choose/xsl:when/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td/xsl:choose/xsl:when[1]/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[1]/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[1]/xsl:choose/and[0]" x="148" y="76"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[1]/xsl:choose/contains[2]" x="148" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[1]/xsl:choose/xsl:when[2]/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[1]/xsl:choose/xsl:otherwise/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[2]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[3]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[3]/xsl:value-of[1]" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[4]/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[4]/xsl:choose/&gt;=[0]" x="148" y="76"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[4]/xsl:choose/xsl:when/xsl:call-template" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[5]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[5]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[5]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[5]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[6]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[6]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[6]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[6]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[7]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[7]/xsl:value-of/number[0]" x="178" y="106"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[7]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[7]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[7]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[8]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[8]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[8]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[8]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[9]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[10]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[11]/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[11]/xsl:choose/&gt;=[0]" x="148" y="76"/>
				<block path="html/body/center/xsl:if[2]/table/tbody/xsl:for-each/tr/td[11]/xsl:choose/xsl:when/xsl:call-template" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each" x="184" y="72"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td/xsl:choose/xsl:when/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td/xsl:choose/xsl:when[1]/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[1]/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[1]/xsl:choose/and[0]" x="148" y="76"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[1]/xsl:choose/contains[2]" x="148" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[1]/xsl:choose/xsl:when[2]/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[1]/xsl:choose/xsl:otherwise/a/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[2]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[3]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[3]/xsl:value-of[1]" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[4]/xsl:for-each" x="164" y="52"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[4]/xsl:for-each/xsl:if" x="194" y="82"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[4]/xsl:for-each/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[5]/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[5]/xsl:choose/&gt;=[0]" x="148" y="76"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[5]/xsl:choose/xsl:when/xsl:call-template" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[6]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[6]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[6]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[6]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[7]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[7]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[7]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[7]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[8]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[8]/xsl:value-of/number[0]" x="178" y="106"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[8]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[8]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[8]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[9]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[9]/xsl:if/&gt;[0]" x="148" y="80"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[9]/xsl:if" x="194" y="82"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[9]/xsl:if/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[10]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[11]/xsl:value-of" x="224" y="112"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[12]/xsl:choose" x="194" y="82"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[12]/xsl:choose/&gt;=[0]" x="148" y="76"/>
				<block path="html/body/center/table[2]/tbody/xsl:for-each/tr/td[12]/xsl:choose/xsl:when/xsl:call-template" x="224" y="112"/>
			</template>
			<template name="javaUTCDateTime"></template>
		</MapperBlockPosition>
		<TemplateContext></TemplateContext>
		<MapperFilter side="source"></MapperFilter>
	</MapperMetaTag>
</metaInformation>
-->